<div class="pull-left">
    <p>
        Current in-game contacts with standings from <strong>{{ organization.name }}</strong><br/>
        This data was last updated at: {{ lastUpdate | date:"SHORT_DATETIME_FORMAT" }}
    </p>
</div>
