# Generated by Django 2.2.13 on 2020-07-08 12:47

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("standingsrequests", "0005_refactor_model_names"),
    ]

    operations = [
        migrations.AddField(
            model_name="standingrevocation",
            name="user",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_DEFAULT,
                to=settings.AUTH_USER_MODEL,
            ),
        ),
        migrations.AlterField(
            model_name="abstractstandingsrequest",
            name="action_date",
            field=models.DateTimeField(
                db_index=True,
                help_text="datetime of action by standing manager",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="abstractstandingsrequest",
            name="is_effective",
            field=models.BooleanField(
                db_index=True,
                default=False,
                help_text="True, when this standing is also set in-game, else False",
            ),
        ),
        migrations.AlterField(
            model_name="alliancecontact",
            name="name",
            field=models.CharField(db_index=True, max_length=254),
        ),
        migrations.AlterField(
            model_name="charactercontact",
            name="name",
            field=models.CharField(db_index=True, max_length=254),
        ),
        migrations.AlterField(
            model_name="contactlabel",
            name="name",
            field=models.CharField(db_index=True, max_length=254),
        ),
        migrations.AlterField(
            model_name="corporationcontact",
            name="name",
            field=models.CharField(db_index=True, max_length=254),
        ),
    ]
