# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-10-06 00:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("standingsrequests", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="contactlabel",
            name="labelID",
            field=models.BigIntegerField(),
        ),
    ]
