{% load bootstrap %}
{% load static %}
{% load i18n %}

{% block page_content %}
    <div class="col-lg-12 container">
        <div class="panel panel-danger">
          <div class="panel-heading">{% trans "Not yet initialized" %}</div>
          <div class="panel-body">
              This app has not yet been initiliazed. Please setup a token to start.
          </div>
        </div>
    </div>
{% endblock page_content %}

{% block extra_script %}
{% endblock extra_script %}
