{% extends 'allianceauth/base.html' %}
{% load i18n %}
{% load static %}

{% block page_title %}{% trans app_title %}{% endblock %}

{% block content %}
    <div class="col-lg-12">
        {% include 'standingsrequests/partials/_menu.html' %}
        <div class="col-lg-12 container">
            {% block page_content %}{% endblock %}
        </div>
    </div>
{% endblock %}

{% block extra_css %}
    {% include "standingsrequests/bundles/angular.html" %}
    <link rel="stylesheet" href="{% static 'standingsrequests/css/global.css' %}" type="text/css" media="screen">
{% endblock extra_css %}
